# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: lockup/v1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from lockup.v1 import lock_pb2 as lockup_dot_v1_dot_lock__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x12lockup/v1/tx.proto\x12\x10nibiru.lockup.v1\x1a\x14gogoproto/gogo.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x14lockup/v1/lock.proto\x1a\x1cgoogle/api/annotations.proto\"\xec\x01\n\rMsgLockTokens\x12\x1f\n\x05owner\x18\x01 \x01(\tB\x10\xf2\xde\x1f\x0cyaml:\"owner\"\x12^\n\x08\x64uration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB1\xc8\xde\x1f\x00\x98\xdf\x1f\x01\xea\xde\x1f\x12\x64uration,omitempty\xf2\xde\x1f\x0fyaml:\"duration\"\x12Z\n\x05\x63oins\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\"(\n\x15MsgLockTokensResponse\x12\x0f\n\x07lock_id\x18\x01 \x01(\x04\"3\n\x11MsgInitiateUnlock\x12\r\n\x05owner\x18\x01 \x01(\t\x12\x0f\n\x07lock_id\x18\x02 \x01(\x04\"\x1b\n\x19MsgInitiateUnlockResponse\"+\n\tMsgUnlock\x12\r\n\x05owner\x18\x01 \x01(\t\x12\x0f\n\x07lock_id\x18\x02 \x01(\x04\"\x13\n\x11MsgUnlockResponse\"\xe7\x01\n\tEventLock\x12\x0f\n\x07lock_id\x18\x01 \x01(\x04\x12\r\n\x05owner\x18\x02 \x01(\t\x12^\n\x08\x64uration\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB1\xc8\xde\x1f\x00\x98\xdf\x1f\x01\xea\xde\x1f\x12\x64uration,omitempty\xf2\xde\x1f\x0fyaml:\"duration\"\x12Z\n\x05\x63oins\x18\x04 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\"\xe1\x01\n\x14\x45ventUnlockInitiated\x12\x0f\n\x07lock_id\x18\x01 \x01(\x04\x12\r\n\x05owner\x18\x02 \x01(\t\x12Z\n\x05\x63oins\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12M\n\x0cunlocking_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x1b\x90\xdf\x1f\x01\xc8\xde\x1f\x00\xf2\xde\x1f\x0fyaml:\"end_time\"\"\x89\x01\n\x0b\x45ventUnlock\x12\x0f\n\x07lock_id\x18\x01 \x01(\x04\x12\r\n\x05owner\x18\x02 \x01(\t\x12Z\n\x05\x63oins\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins2\xf5\x02\n\x03Msg\x12z\n\nLockTokens\x12\x1f.nibiru.lockup.v1.MsgLockTokens\x1a\'.nibiru.lockup.v1.MsgLockTokensResponse\"\"\x82\xd3\xe4\x93\x02\x1c\"\x1a/nibiru/lockup/lock_tokens\x12\x86\x01\n\x0eInitiateUnlock\x12#.nibiru.lockup.v1.MsgInitiateUnlock\x1a+.nibiru.lockup.v1.MsgInitiateUnlockResponse\"\"\x82\xd3\xe4\x93\x02\x1c\"\x1a/nibiru/lockup/init_unlock\x12i\n\x06Unlock\x12\x1b.nibiru.lockup.v1.MsgUnlock\x1a#.nibiru.lockup.v1.MsgUnlockResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x15/nibiru/lockup/unlockB.Z,github.com/NibiruChain/nibiru/x/lockup/typesb\x06proto3'
)


_MSGLOCKTOKENS = DESCRIPTOR.message_types_by_name['MsgLockTokens']
_MSGLOCKTOKENSRESPONSE = DESCRIPTOR.message_types_by_name['MsgLockTokensResponse']
_MSGINITIATEUNLOCK = DESCRIPTOR.message_types_by_name['MsgInitiateUnlock']
_MSGINITIATEUNLOCKRESPONSE = DESCRIPTOR.message_types_by_name['MsgInitiateUnlockResponse']
_MSGUNLOCK = DESCRIPTOR.message_types_by_name['MsgUnlock']
_MSGUNLOCKRESPONSE = DESCRIPTOR.message_types_by_name['MsgUnlockResponse']
_EVENTLOCK = DESCRIPTOR.message_types_by_name['EventLock']
_EVENTUNLOCKINITIATED = DESCRIPTOR.message_types_by_name['EventUnlockInitiated']
_EVENTUNLOCK = DESCRIPTOR.message_types_by_name['EventUnlock']
MsgLockTokens = _reflection.GeneratedProtocolMessageType(
    'MsgLockTokens',
    (_message.Message,),
    {
        'DESCRIPTOR': _MSGLOCKTOKENS,
        '__module__': 'lockup.v1.tx_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.lockup.v1.MsgLockTokens)
    },
)
_sym_db.RegisterMessage(MsgLockTokens)

MsgLockTokensResponse = _reflection.GeneratedProtocolMessageType(
    'MsgLockTokensResponse',
    (_message.Message,),
    {
        'DESCRIPTOR': _MSGLOCKTOKENSRESPONSE,
        '__module__': 'lockup.v1.tx_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.lockup.v1.MsgLockTokensResponse)
    },
)
_sym_db.RegisterMessage(MsgLockTokensResponse)

MsgInitiateUnlock = _reflection.GeneratedProtocolMessageType(
    'MsgInitiateUnlock',
    (_message.Message,),
    {
        'DESCRIPTOR': _MSGINITIATEUNLOCK,
        '__module__': 'lockup.v1.tx_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.lockup.v1.MsgInitiateUnlock)
    },
)
_sym_db.RegisterMessage(MsgInitiateUnlock)

MsgInitiateUnlockResponse = _reflection.GeneratedProtocolMessageType(
    'MsgInitiateUnlockResponse',
    (_message.Message,),
    {
        'DESCRIPTOR': _MSGINITIATEUNLOCKRESPONSE,
        '__module__': 'lockup.v1.tx_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.lockup.v1.MsgInitiateUnlockResponse)
    },
)
_sym_db.RegisterMessage(MsgInitiateUnlockResponse)

MsgUnlock = _reflection.GeneratedProtocolMessageType(
    'MsgUnlock',
    (_message.Message,),
    {
        'DESCRIPTOR': _MSGUNLOCK,
        '__module__': 'lockup.v1.tx_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.lockup.v1.MsgUnlock)
    },
)
_sym_db.RegisterMessage(MsgUnlock)

MsgUnlockResponse = _reflection.GeneratedProtocolMessageType(
    'MsgUnlockResponse',
    (_message.Message,),
    {
        'DESCRIPTOR': _MSGUNLOCKRESPONSE,
        '__module__': 'lockup.v1.tx_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.lockup.v1.MsgUnlockResponse)
    },
)
_sym_db.RegisterMessage(MsgUnlockResponse)

EventLock = _reflection.GeneratedProtocolMessageType(
    'EventLock',
    (_message.Message,),
    {
        'DESCRIPTOR': _EVENTLOCK,
        '__module__': 'lockup.v1.tx_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.lockup.v1.EventLock)
    },
)
_sym_db.RegisterMessage(EventLock)

EventUnlockInitiated = _reflection.GeneratedProtocolMessageType(
    'EventUnlockInitiated',
    (_message.Message,),
    {
        'DESCRIPTOR': _EVENTUNLOCKINITIATED,
        '__module__': 'lockup.v1.tx_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.lockup.v1.EventUnlockInitiated)
    },
)
_sym_db.RegisterMessage(EventUnlockInitiated)

EventUnlock = _reflection.GeneratedProtocolMessageType(
    'EventUnlock',
    (_message.Message,),
    {
        'DESCRIPTOR': _EVENTUNLOCK,
        '__module__': 'lockup.v1.tx_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.lockup.v1.EventUnlock)
    },
)
_sym_db.RegisterMessage(EventUnlock)

_MSG = DESCRIPTOR.services_by_name['Msg']
if _descriptor._USE_C_DESCRIPTORS == False:

    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z,github.com/NibiruChain/nibiru/x/lockup/types'
    _MSGLOCKTOKENS.fields_by_name['owner']._options = None
    _MSGLOCKTOKENS.fields_by_name['owner']._serialized_options = b'\362\336\037\014yaml:\"owner\"'
    _MSGLOCKTOKENS.fields_by_name['duration']._options = None
    _MSGLOCKTOKENS.fields_by_name[
        'duration'
    ]._serialized_options = (
        b'\310\336\037\000\230\337\037\001\352\336\037\022duration,omitempty\362\336\037\017yaml:\"duration\"'
    )
    _MSGLOCKTOKENS.fields_by_name['coins']._options = None
    _MSGLOCKTOKENS.fields_by_name[
        'coins'
    ]._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
    _EVENTLOCK.fields_by_name['duration']._options = None
    _EVENTLOCK.fields_by_name[
        'duration'
    ]._serialized_options = (
        b'\310\336\037\000\230\337\037\001\352\336\037\022duration,omitempty\362\336\037\017yaml:\"duration\"'
    )
    _EVENTLOCK.fields_by_name['coins']._options = None
    _EVENTLOCK.fields_by_name[
        'coins'
    ]._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
    _EVENTUNLOCKINITIATED.fields_by_name['coins']._options = None
    _EVENTUNLOCKINITIATED.fields_by_name[
        'coins'
    ]._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
    _EVENTUNLOCKINITIATED.fields_by_name['unlocking_at']._options = None
    _EVENTUNLOCKINITIATED.fields_by_name[
        'unlocking_at'
    ]._serialized_options = b'\220\337\037\001\310\336\037\000\362\336\037\017yaml:\"end_time\"'
    _EVENTUNLOCK.fields_by_name['coins']._options = None
    _EVENTUNLOCK.fields_by_name[
        'coins'
    ]._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
    _MSG.methods_by_name['LockTokens']._options = None
    _MSG.methods_by_name['LockTokens']._serialized_options = b'\202\323\344\223\002\034\"\032/nibiru/lockup/lock_tokens'
    _MSG.methods_by_name['InitiateUnlock']._options = None
    _MSG.methods_by_name[
        'InitiateUnlock'
    ]._serialized_options = b'\202\323\344\223\002\034\"\032/nibiru/lockup/init_unlock'
    _MSG.methods_by_name['Unlock']._options = None
    _MSG.methods_by_name['Unlock']._serialized_options = b'\202\323\344\223\002\027\"\025/nibiru/lockup/unlock'
    _MSGLOCKTOKENS._serialized_start = 212
    _MSGLOCKTOKENS._serialized_end = 448
    _MSGLOCKTOKENSRESPONSE._serialized_start = 450
    _MSGLOCKTOKENSRESPONSE._serialized_end = 490
    _MSGINITIATEUNLOCK._serialized_start = 492
    _MSGINITIATEUNLOCK._serialized_end = 543
    _MSGINITIATEUNLOCKRESPONSE._serialized_start = 545
    _MSGINITIATEUNLOCKRESPONSE._serialized_end = 572
    _MSGUNLOCK._serialized_start = 574
    _MSGUNLOCK._serialized_end = 617
    _MSGUNLOCKRESPONSE._serialized_start = 619
    _MSGUNLOCKRESPONSE._serialized_end = 638
    _EVENTLOCK._serialized_start = 641
    _EVENTLOCK._serialized_end = 872
    _EVENTUNLOCKINITIATED._serialized_start = 875
    _EVENTUNLOCKINITIATED._serialized_end = 1100
    _EVENTUNLOCK._serialized_start = 1103
    _EVENTUNLOCK._serialized_end = 1240
    _MSG._serialized_start = 1243
    _MSG._serialized_end = 1616
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: perp/v1/state.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from common import common_pb2 as common_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13perp/v1/state.proto\x12\x0enibiru.perp.v1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x13\x63ommon/common.proto\"\xca\x04\n\x06Params\x12\x0f\n\x07stopped\x18\x01 \x01(\x08\x12P\n\x18maintenance_margin_ratio\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12J\n\x12\x66\x65\x65_pool_fee_ratio\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12P\n\x18\x65\x63osystem_fund_fee_ratio\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12M\n\x15liquidation_fee_ratio\x18\x05 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12Q\n\x19partial_liquidation_ratio\x18\x06 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x18\n\x10\x65poch_identifier\x18\x07 \x01(\t\x12\x82\x01\n\x14twap_lookback_window\x18\x08 \x01(\x0b\x32\x19.google.protobuf.DurationBI\xc8\xde\x1f\x00\x98\xdf\x1f\x01\xea\xde\x1f\x1etwap_lookback_window,omitempty\xf2\xde\x1f\x1byaml:\"twap_lookback_window\"\"\x88\x04\n\x0cGenesisState\x12,\n\x06params\x18\x01 \x01(\x0b\x32\x16.nibiru.perp.v1.ParamsB\x04\xc8\xde\x1f\x00\x12W\n\rvault_balance\x18\x02 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB%\xf2\xde\x1f\x1dyaml:\"module_account_balance\"\xc8\xde\x1f\x00\x12Y\n\x0fperp_ef_balance\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB%\xf2\xde\x1f\x1dyaml:\"module_account_balance\"\xc8\xde\x1f\x00\x12Z\n\x10\x66\x65\x65_pool_balance\x18\x04 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB%\xf2\xde\x1f\x1dyaml:\"module_account_balance\"\xc8\xde\x1f\x00\x12\x33\n\rpair_metadata\x18\x05 \x03(\x0b\x32\x1c.nibiru.perp.v1.PairMetadata\x12+\n\tpositions\x18\x06 \x03(\x0b\x32\x18.nibiru.perp.v1.Position\x12\x39\n\x11prepaid_bad_debts\x18\x07 \x03(\x0b\x32\x1e.nibiru.perp.v1.PrepaidBadDebt\x12\x1d\n\x15whitelisted_addresses\x18\x08 \x03(\t\"\x8c\x03\n\x08Position\x12\x16\n\x0etrader_address\x18\x01 \x01(\t\x12,\n\x04pair\x18\x02 \x01(\x0b\x32\x18.nibiru.common.AssetPairB\x04\xc8\xde\x1f\x00\x12<\n\x04size\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12>\n\x06margin\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x45\n\ropen_notional\x18\x05 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12_\n\'last_update_cumulative_premium_fraction\x18\x06 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x14\n\x0c\x62lock_number\x18\x07 \x01(\x03\"\x90\x05\n\x0cPositionResp\x12*\n\x08position\x18\x01 \x01(\x0b\x32\x18.nibiru.perp.v1.Position\x12P\n\x18\x65xchanged_notional_value\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12O\n\x17\x65xchanged_position_size\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12@\n\x08\x62\x61\x64_debt\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12G\n\x0f\x66unding_payment\x18\x05 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x44\n\x0crealized_pnl\x18\x06 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12L\n\x14unrealized_pnl_after\x18\x07 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12G\n\x0fmargin_to_vault\x18\x08 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12I\n\x11position_notional\x18\t \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"\xb9\x02\n\rLiquidateResp\x12@\n\x08\x62\x61\x64_debt\x18\x01 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12I\n\x11\x66\x65\x65_to_liquidator\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12R\n\x1a\x66\x65\x65_to_perp_ecosystem_fund\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12\x12\n\nliquidator\x18\x04 \x01(\t\x12\x33\n\rposition_resp\x18\x05 \x01(\x0b\x32\x1c.nibiru.perp.v1.PositionResp\"\x92\x01\n\x0cPairMetadata\x12,\n\x04pair\x18\x01 \x01(\x0b\x32\x18.nibiru.common.AssetPairB\x04\xc8\xde\x1f\x00\x12T\n\x1c\x63umulative_premium_fractions\x18\x02 \x03(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"_\n\x0ePrepaidBadDebt\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12>\n\x06\x61mount\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00*/\n\x04Side\x12\x14\n\x10SIDE_UNSPECIFIED\x10\x00\x12\x07\n\x03\x42UY\x10\x01\x12\x08\n\x04SELL\x10\x02*V\n\rPnLCalcOption\x12\x1f\n\x1bPNL_CALC_OPTION_UNSPECIFIED\x10\x00\x12\x0e\n\nSPOT_PRICE\x10\x01\x12\x08\n\x04TWAP\x10\x02\x12\n\n\x06ORACLE\x10\x03*G\n\x13PnLPreferenceOption\x12\x1e\n\x1aPNL_PREFERENCE_UNSPECIFIED\x10\x00\x12\x07\n\x03MAX\x10\x01\x12\x07\n\x03MIN\x10\x02*q\n\x1cMarginCalculationPriceOption\x12/\n+MARGIN_CALCULATION_PRICE_OPTION_UNSPECIFIED\x10\x00\x12\x08\n\x04SPOT\x10\x01\x12\t\n\x05INDEX\x10\x02\x12\x0b\n\x07MAX_PNL\x10\x03\x42,Z*github.com/NibiruChain/nibiru/x/perp/typesb\x06proto3')

_SIDE = DESCRIPTOR.enum_types_by_name['Side']
Side = enum_type_wrapper.EnumTypeWrapper(_SIDE)
_PNLCALCOPTION = DESCRIPTOR.enum_types_by_name['PnLCalcOption']
PnLCalcOption = enum_type_wrapper.EnumTypeWrapper(_PNLCALCOPTION)
_PNLPREFERENCEOPTION = DESCRIPTOR.enum_types_by_name['PnLPreferenceOption']
PnLPreferenceOption = enum_type_wrapper.EnumTypeWrapper(_PNLPREFERENCEOPTION)
_MARGINCALCULATIONPRICEOPTION = DESCRIPTOR.enum_types_by_name['MarginCalculationPriceOption']
MarginCalculationPriceOption = enum_type_wrapper.EnumTypeWrapper(_MARGINCALCULATIONPRICEOPTION)
SIDE_UNSPECIFIED = 0
BUY = 1
SELL = 2
PNL_CALC_OPTION_UNSPECIFIED = 0
SPOT_PRICE = 1
TWAP = 2
ORACLE = 3
PNL_PREFERENCE_UNSPECIFIED = 0
MAX = 1
MIN = 2
MARGIN_CALCULATION_PRICE_OPTION_UNSPECIFIED = 0
SPOT = 1
INDEX = 2
MAX_PNL = 3


_PARAMS = DESCRIPTOR.message_types_by_name['Params']
_GENESISSTATE = DESCRIPTOR.message_types_by_name['GenesisState']
_POSITION = DESCRIPTOR.message_types_by_name['Position']
_POSITIONRESP = DESCRIPTOR.message_types_by_name['PositionResp']
_LIQUIDATERESP = DESCRIPTOR.message_types_by_name['LiquidateResp']
_PAIRMETADATA = DESCRIPTOR.message_types_by_name['PairMetadata']
_PREPAIDBADDEBT = DESCRIPTOR.message_types_by_name['PrepaidBadDebt']
Params = _reflection.GeneratedProtocolMessageType('Params', (_message.Message,), {
  'DESCRIPTOR' : _PARAMS,
  '__module__' : 'perp.v1.state_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.perp.v1.Params)
  })
_sym_db.RegisterMessage(Params)

GenesisState = _reflection.GeneratedProtocolMessageType('GenesisState', (_message.Message,), {
  'DESCRIPTOR' : _GENESISSTATE,
  '__module__' : 'perp.v1.state_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.perp.v1.GenesisState)
  })
_sym_db.RegisterMessage(GenesisState)

Position = _reflection.GeneratedProtocolMessageType('Position', (_message.Message,), {
  'DESCRIPTOR' : _POSITION,
  '__module__' : 'perp.v1.state_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.perp.v1.Position)
  })
_sym_db.RegisterMessage(Position)

PositionResp = _reflection.GeneratedProtocolMessageType('PositionResp', (_message.Message,), {
  'DESCRIPTOR' : _POSITIONRESP,
  '__module__' : 'perp.v1.state_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.perp.v1.PositionResp)
  })
_sym_db.RegisterMessage(PositionResp)

LiquidateResp = _reflection.GeneratedProtocolMessageType('LiquidateResp', (_message.Message,), {
  'DESCRIPTOR' : _LIQUIDATERESP,
  '__module__' : 'perp.v1.state_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.perp.v1.LiquidateResp)
  })
_sym_db.RegisterMessage(LiquidateResp)

PairMetadata = _reflection.GeneratedProtocolMessageType('PairMetadata', (_message.Message,), {
  'DESCRIPTOR' : _PAIRMETADATA,
  '__module__' : 'perp.v1.state_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.perp.v1.PairMetadata)
  })
_sym_db.RegisterMessage(PairMetadata)

PrepaidBadDebt = _reflection.GeneratedProtocolMessageType('PrepaidBadDebt', (_message.Message,), {
  'DESCRIPTOR' : _PREPAIDBADDEBT,
  '__module__' : 'perp.v1.state_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.perp.v1.PrepaidBadDebt)
  })
_sym_db.RegisterMessage(PrepaidBadDebt)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z*github.com/NibiruChain/nibiru/x/perp/types'
  _PARAMS.fields_by_name['maintenance_margin_ratio']._options = None
  _PARAMS.fields_by_name['maintenance_margin_ratio']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _PARAMS.fields_by_name['fee_pool_fee_ratio']._options = None
  _PARAMS.fields_by_name['fee_pool_fee_ratio']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _PARAMS.fields_by_name['ecosystem_fund_fee_ratio']._options = None
  _PARAMS.fields_by_name['ecosystem_fund_fee_ratio']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _PARAMS.fields_by_name['liquidation_fee_ratio']._options = None
  _PARAMS.fields_by_name['liquidation_fee_ratio']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _PARAMS.fields_by_name['partial_liquidation_ratio']._options = None
  _PARAMS.fields_by_name['partial_liquidation_ratio']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _PARAMS.fields_by_name['twap_lookback_window']._options = None
  _PARAMS.fields_by_name['twap_lookback_window']._serialized_options = b'\310\336\037\000\230\337\037\001\352\336\037\036twap_lookback_window,omitempty\362\336\037\033yaml:\"twap_lookback_window\"'
  _GENESISSTATE.fields_by_name['params']._options = None
  _GENESISSTATE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _GENESISSTATE.fields_by_name['vault_balance']._options = None
  _GENESISSTATE.fields_by_name['vault_balance']._serialized_options = b'\362\336\037\035yaml:\"module_account_balance\"\310\336\037\000'
  _GENESISSTATE.fields_by_name['perp_ef_balance']._options = None
  _GENESISSTATE.fields_by_name['perp_ef_balance']._serialized_options = b'\362\336\037\035yaml:\"module_account_balance\"\310\336\037\000'
  _GENESISSTATE.fields_by_name['fee_pool_balance']._options = None
  _GENESISSTATE.fields_by_name['fee_pool_balance']._serialized_options = b'\362\336\037\035yaml:\"module_account_balance\"\310\336\037\000'
  _POSITION.fields_by_name['pair']._options = None
  _POSITION.fields_by_name['pair']._serialized_options = b'\310\336\037\000'
  _POSITION.fields_by_name['size']._options = None
  _POSITION.fields_by_name['size']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _POSITION.fields_by_name['margin']._options = None
  _POSITION.fields_by_name['margin']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _POSITION.fields_by_name['open_notional']._options = None
  _POSITION.fields_by_name['open_notional']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _POSITION.fields_by_name['last_update_cumulative_premium_fraction']._options = None
  _POSITION.fields_by_name['last_update_cumulative_premium_fraction']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _POSITIONRESP.fields_by_name['exchanged_notional_value']._options = None
  _POSITIONRESP.fields_by_name['exchanged_notional_value']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _POSITIONRESP.fields_by_name['exchanged_position_size']._options = None
  _POSITIONRESP.fields_by_name['exchanged_position_size']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _POSITIONRESP.fields_by_name['bad_debt']._options = None
  _POSITIONRESP.fields_by_name['bad_debt']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _POSITIONRESP.fields_by_name['funding_payment']._options = None
  _POSITIONRESP.fields_by_name['funding_payment']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _POSITIONRESP.fields_by_name['realized_pnl']._options = None
  _POSITIONRESP.fields_by_name['realized_pnl']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _POSITIONRESP.fields_by_name['unrealized_pnl_after']._options = None
  _POSITIONRESP.fields_by_name['unrealized_pnl_after']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _POSITIONRESP.fields_by_name['margin_to_vault']._options = None
  _POSITIONRESP.fields_by_name['margin_to_vault']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _POSITIONRESP.fields_by_name['position_notional']._options = None
  _POSITIONRESP.fields_by_name['position_notional']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _LIQUIDATERESP.fields_by_name['bad_debt']._options = None
  _LIQUIDATERESP.fields_by_name['bad_debt']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000'
  _LIQUIDATERESP.fields_by_name['fee_to_liquidator']._options = None
  _LIQUIDATERESP.fields_by_name['fee_to_liquidator']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000'
  _LIQUIDATERESP.fields_by_name['fee_to_perp_ecosystem_fund']._options = None
  _LIQUIDATERESP.fields_by_name['fee_to_perp_ecosystem_fund']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000'
  _PAIRMETADATA.fields_by_name['pair']._options = None
  _PAIRMETADATA.fields_by_name['pair']._serialized_options = b'\310\336\037\000'
  _PAIRMETADATA.fields_by_name['cumulative_premium_fractions']._options = None
  _PAIRMETADATA.fields_by_name['cumulative_premium_fractions']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _PREPAIDBADDEBT.fields_by_name['amount']._options = None
  _PREPAIDBADDEBT.fields_by_name['amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000'
  _SIDE._serialized_start=2905
  _SIDE._serialized_end=2952
  _PNLCALCOPTION._serialized_start=2954
  _PNLCALCOPTION._serialized_end=3040
  _PNLPREFERENCEOPTION._serialized_start=3042
  _PNLPREFERENCEOPTION._serialized_end=3113
  _MARGINCALCULATIONPRICEOPTION._serialized_start=3115
  _MARGINCALCULATIONPRICEOPTION._serialized_end=3228
  _PARAMS._serialized_start=174
  _PARAMS._serialized_end=760
  _GENESISSTATE._serialized_start=763
  _GENESISSTATE._serialized_end=1283
  _POSITION._serialized_start=1286
  _POSITION._serialized_end=1682
  _POSITIONRESP._serialized_start=1685
  _POSITIONRESP._serialized_end=2341
  _LIQUIDATERESP._serialized_start=2344
  _LIQUIDATERESP._serialized_end=2657
  _PAIRMETADATA._serialized_start=2660
  _PAIRMETADATA._serialized_end=2806
  _PREPAIDBADDEBT._serialized_start=2808
  _PREPAIDBADDEBT._serialized_end=2903
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/crypto/secp256r1/keys.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"cosmos/crypto/secp256r1/keys.proto\x12\x17\x63osmos.crypto.secp256r1\x1a\x14gogoproto/gogo.proto\"\"\n\x06PubKey\x12\x18\n\x03key\x18\x01 \x01(\x0c\x42\x0b\xda\xde\x1f\x07\x65\x63\x64saPK\"&\n\x07PrivKey\x12\x1b\n\x06secret\x18\x01 \x01(\x0c\x42\x0b\xda\xde\x1f\x07\x65\x63\x64saSKB@Z2github.com/cosmos/cosmos-sdk/crypto/keys/secp256r1\xc8\xe3\x1e\x01\xd8\xe1\x1e\x00\xc8\xe1\x1e\x00\x62\x06proto3')



_PUBKEY = DESCRIPTOR.message_types_by_name['PubKey']
_PRIVKEY = DESCRIPTOR.message_types_by_name['PrivKey']
PubKey = _reflection.GeneratedProtocolMessageType('PubKey', (_message.Message,), {
  'DESCRIPTOR' : _PUBKEY,
  '__module__' : 'cosmos.crypto.secp256r1.keys_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.crypto.secp256r1.PubKey)
  })
_sym_db.RegisterMessage(PubKey)

PrivKey = _reflection.GeneratedProtocolMessageType('PrivKey', (_message.Message,), {
  'DESCRIPTOR' : _PRIVKEY,
  '__module__' : 'cosmos.crypto.secp256r1.keys_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.crypto.secp256r1.PrivKey)
  })
_sym_db.RegisterMessage(PrivKey)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z2github.com/cosmos/cosmos-sdk/crypto/keys/secp256r1\310\343\036\001\330\341\036\000\310\341\036\000'
  _PUBKEY.fields_by_name['key']._options = None
  _PUBKEY.fields_by_name['key']._serialized_options = b'\332\336\037\007ecdsaPK'
  _PRIVKEY.fields_by_name['secret']._options = None
  _PRIVKEY.fields_by_name['secret']._serialized_options = b'\332\336\037\007ecdsaSK'
  _PUBKEY._serialized_start=85
  _PUBKEY._serialized_end=119
  _PRIVKEY._serialized_start=121
  _PRIVKEY._serialized_end=159
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vpool/v1/event.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14vpool/v1/event.proto\x12\x0fnibiru.vpool.v1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb6\x01\n\x19ReserveSnapshotSavedEvent\x12\x0c\n\x04pair\x18\x01 \x01(\t\x12\x45\n\rquote_reserve\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x44\n\x0c\x62\x61se_reserve\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"\xb0\x01\n\x15SwapQuoteForBaseEvent\x12\x0c\n\x04pair\x18\x01 \x01(\t\x12\x44\n\x0cquote_amount\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x43\n\x0b\x62\x61se_amount\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"\xb0\x01\n\x15SwapBaseForQuoteEvent\x12\x0c\n\x04pair\x18\x01 \x01(\t\x12\x44\n\x0cquote_amount\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x43\n\x0b\x62\x61se_amount\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"\x98\x01\n\x10MarkPriceChanged\x12\x0c\n\x04pair\x18\x01 \x01(\t\x12=\n\x05price\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x37\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\x90\xdf\x1f\x01\xc8\xde\x1f\x00\x42-Z+github.com/NibiruChain/nibiru/x/vpool/typesb\x06proto3')



_RESERVESNAPSHOTSAVEDEVENT = DESCRIPTOR.message_types_by_name['ReserveSnapshotSavedEvent']
_SWAPQUOTEFORBASEEVENT = DESCRIPTOR.message_types_by_name['SwapQuoteForBaseEvent']
_SWAPBASEFORQUOTEEVENT = DESCRIPTOR.message_types_by_name['SwapBaseForQuoteEvent']
_MARKPRICECHANGED = DESCRIPTOR.message_types_by_name['MarkPriceChanged']
ReserveSnapshotSavedEvent = _reflection.GeneratedProtocolMessageType('ReserveSnapshotSavedEvent', (_message.Message,), {
  'DESCRIPTOR' : _RESERVESNAPSHOTSAVEDEVENT,
  '__module__' : 'vpool.v1.event_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.vpool.v1.ReserveSnapshotSavedEvent)
  })
_sym_db.RegisterMessage(ReserveSnapshotSavedEvent)

SwapQuoteForBaseEvent = _reflection.GeneratedProtocolMessageType('SwapQuoteForBaseEvent', (_message.Message,), {
  'DESCRIPTOR' : _SWAPQUOTEFORBASEEVENT,
  '__module__' : 'vpool.v1.event_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.vpool.v1.SwapQuoteForBaseEvent)
  })
_sym_db.RegisterMessage(SwapQuoteForBaseEvent)

SwapBaseForQuoteEvent = _reflection.GeneratedProtocolMessageType('SwapBaseForQuoteEvent', (_message.Message,), {
  'DESCRIPTOR' : _SWAPBASEFORQUOTEEVENT,
  '__module__' : 'vpool.v1.event_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.vpool.v1.SwapBaseForQuoteEvent)
  })
_sym_db.RegisterMessage(SwapBaseForQuoteEvent)

MarkPriceChanged = _reflection.GeneratedProtocolMessageType('MarkPriceChanged', (_message.Message,), {
  'DESCRIPTOR' : _MARKPRICECHANGED,
  '__module__' : 'vpool.v1.event_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.vpool.v1.MarkPriceChanged)
  })
_sym_db.RegisterMessage(MarkPriceChanged)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/NibiruChain/nibiru/x/vpool/types'
  _RESERVESNAPSHOTSAVEDEVENT.fields_by_name['quote_reserve']._options = None
  _RESERVESNAPSHOTSAVEDEVENT.fields_by_name['quote_reserve']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _RESERVESNAPSHOTSAVEDEVENT.fields_by_name['base_reserve']._options = None
  _RESERVESNAPSHOTSAVEDEVENT.fields_by_name['base_reserve']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _SWAPQUOTEFORBASEEVENT.fields_by_name['quote_amount']._options = None
  _SWAPQUOTEFORBASEEVENT.fields_by_name['quote_amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _SWAPQUOTEFORBASEEVENT.fields_by_name['base_amount']._options = None
  _SWAPQUOTEFORBASEEVENT.fields_by_name['base_amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _SWAPBASEFORQUOTEEVENT.fields_by_name['quote_amount']._options = None
  _SWAPBASEFORQUOTEEVENT.fields_by_name['quote_amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _SWAPBASEFORQUOTEEVENT.fields_by_name['base_amount']._options = None
  _SWAPBASEFORQUOTEEVENT.fields_by_name['base_amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _MARKPRICECHANGED.fields_by_name['price']._options = None
  _MARKPRICECHANGED.fields_by_name['price']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _MARKPRICECHANGED.fields_by_name['timestamp']._options = None
  _MARKPRICECHANGED.fields_by_name['timestamp']._serialized_options = b'\220\337\037\001\310\336\037\000'
  _RESERVESNAPSHOTSAVEDEVENT._serialized_start=156
  _RESERVESNAPSHOTSAVEDEVENT._serialized_end=338
  _SWAPQUOTEFORBASEEVENT._serialized_start=341
  _SWAPQUOTEFORBASEEVENT._serialized_end=517
  _SWAPBASEFORQUOTEEVENT._serialized_start=520
  _SWAPBASEFORQUOTEEVENT._serialized_end=696
  _MARKPRICECHANGED._serialized_start=699
  _MARKPRICECHANGED._serialized_end=851
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/staking/v1beta1/staking.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from tendermint.types import types_pb2 as tendermint_dot_types_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$cosmos/staking/v1beta1/staking.proto\x12\x16\x63osmos.staking.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x1ctendermint/types/types.proto\"y\n\x0eHistoricalInfo\x12.\n\x06header\x18\x01 \x01(\x0b\x32\x18.tendermint.types.HeaderB\x04\xc8\xde\x1f\x00\x12\x37\n\x06valset\x18\x02 \x03(\x0b\x32!.cosmos.staking.v1beta1.ValidatorB\x04\xc8\xde\x1f\x00\"\x91\x02\n\x0f\x43ommissionRates\x12<\n\x04rate\x18\x01 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12S\n\x08max_rate\x18\x02 \x01(\tBA\xf2\xde\x1f\x0fyaml:\"max_rate\"\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x61\n\x0fmax_change_rate\x18\x03 \x01(\tBH\xf2\xde\x1f\x16yaml:\"max_change_rate\"\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x01\x98\xa0\x1f\x00\"\xb4\x01\n\nCommission\x12K\n\x10\x63ommission_rates\x18\x01 \x01(\x0b\x32\'.cosmos.staking.v1beta1.CommissionRatesB\x08\xd0\xde\x1f\x01\xc8\xde\x1f\x00\x12O\n\x0bupdate_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x1e\xc8\xde\x1f\x00\x90\xdf\x1f\x01\xf2\xde\x1f\x12yaml:\"update_time\":\x08\xe8\xa0\x1f\x01\x98\xa0\x1f\x00\"\x93\x01\n\x0b\x44\x65scription\x12\x0f\n\x07moniker\x18\x01 \x01(\t\x12\x10\n\x08identity\x18\x02 \x01(\t\x12\x0f\n\x07website\x18\x03 \x01(\t\x12\x35\n\x10security_contact\x18\x04 \x01(\tB\x1b\xf2\xde\x1f\x17yaml:\"security_contact\"\x12\x0f\n\x07\x64\x65tails\x18\x05 \x01(\t:\x08\xe8\xa0\x1f\x01\x98\xa0\x1f\x00\"\x95\x06\n\tValidator\x12\x35\n\x10operator_address\x18\x01 \x01(\tB\x1b\xf2\xde\x1f\x17yaml:\"operator_address\"\x12\x63\n\x10\x63onsensus_pubkey\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyB3\xca\xb4-\x14\x63osmos.crypto.PubKey\xf2\xde\x1f\x17yaml:\"consensus_pubkey\"\x12\x0e\n\x06jailed\x18\x03 \x01(\x08\x12\x32\n\x06status\x18\x04 \x01(\x0e\x32\".cosmos.staking.v1beta1.BondStatus\x12>\n\x06tokens\x18\x05 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12\x63\n\x10\x64\x65legator_shares\x18\x06 \x01(\tBI\xf2\xde\x1f\x17yaml:\"delegator_shares\"\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12>\n\x0b\x64\x65scription\x18\x07 \x01(\x0b\x32#.cosmos.staking.v1beta1.DescriptionB\x04\xc8\xde\x1f\x00\x12\x35\n\x10unbonding_height\x18\x08 \x01(\x03\x42\x1b\xf2\xde\x1f\x17yaml:\"unbonding_height\"\x12U\n\x0eunbonding_time\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampB!\xc8\xde\x1f\x00\x90\xdf\x1f\x01\xf2\xde\x1f\x15yaml:\"unbonding_time\"\x12<\n\ncommission\x18\n \x01(\x0b\x32\".cosmos.staking.v1beta1.CommissionB\x04\xc8\xde\x1f\x00\x12i\n\x13min_self_delegation\x18\x0b \x01(\tBL\xf2\xde\x1f\x1ayaml:\"min_self_delegation\"\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00:\x0c\xe8\xa0\x1f\x00\x98\xa0\x1f\x00\x88\xa0\x1f\x00\"+\n\x0cValAddresses\x12\x11\n\taddresses\x18\x01 \x03(\t:\x08\x98\xa0\x1f\x00\x80\xdc \x01\"\x88\x01\n\x06\x44VPair\x12\x37\n\x11\x64\x65legator_address\x18\x01 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:\"delegator_address\"\x12\x37\n\x11validator_address\x18\x02 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:\"validator_address\":\x0c\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\x98\xa0\x1f\x00\">\n\x07\x44VPairs\x12\x33\n\x05pairs\x18\x01 \x03(\x0b\x32\x1e.cosmos.staking.v1beta1.DVPairB\x04\xc8\xde\x1f\x00\"\xd5\x01\n\nDVVTriplet\x12\x37\n\x11\x64\x65legator_address\x18\x01 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:\"delegator_address\"\x12?\n\x15validator_src_address\x18\x02 \x01(\tB \xf2\xde\x1f\x1cyaml:\"validator_src_address\"\x12?\n\x15validator_dst_address\x18\x03 \x01(\tB \xf2\xde\x1f\x1cyaml:\"validator_dst_address\":\x0c\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\x98\xa0\x1f\x00\"I\n\x0b\x44VVTriplets\x12:\n\x08triplets\x18\x01 \x03(\x0b\x32\".cosmos.staking.v1beta1.DVVTripletB\x04\xc8\xde\x1f\x00\"\xcc\x01\n\nDelegation\x12\x37\n\x11\x64\x65legator_address\x18\x01 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:\"delegator_address\"\x12\x37\n\x11validator_address\x18\x02 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:\"validator_address\"\x12>\n\x06shares\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00:\x0c\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\x98\xa0\x1f\x00\"\xde\x01\n\x13UnbondingDelegation\x12\x37\n\x11\x64\x65legator_address\x18\x01 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:\"delegator_address\"\x12\x37\n\x11validator_address\x18\x02 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:\"validator_address\"\x12G\n\x07\x65ntries\x18\x03 \x03(\x0b\x32\x30.cosmos.staking.v1beta1.UnbondingDelegationEntryB\x04\xc8\xde\x1f\x00:\x0c\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\x98\xa0\x1f\x00\"\xd6\x02\n\x18UnbondingDelegationEntry\x12\x33\n\x0f\x63reation_height\x18\x01 \x01(\x03\x42\x1a\xf2\xde\x1f\x16yaml:\"creation_height\"\x12W\n\x0f\x63ompletion_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\"\xc8\xde\x1f\x00\x90\xdf\x1f\x01\xf2\xde\x1f\x16yaml:\"completion_time\"\x12\x61\n\x0finitial_balance\x18\x03 \x01(\tBH\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\xf2\xde\x1f\x16yaml:\"initial_balance\"\x12?\n\x07\x62\x61lance\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x01\x98\xa0\x1f\x00\"\xd2\x02\n\x11RedelegationEntry\x12\x33\n\x0f\x63reation_height\x18\x01 \x01(\x03\x42\x1a\xf2\xde\x1f\x16yaml:\"creation_height\"\x12W\n\x0f\x63ompletion_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\"\xc8\xde\x1f\x00\x90\xdf\x1f\x01\xf2\xde\x1f\x16yaml:\"completion_time\"\x12\x61\n\x0finitial_balance\x18\x03 \x01(\tBH\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\xf2\xde\x1f\x16yaml:\"initial_balance\"\x12\x42\n\nshares_dst\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x01\x98\xa0\x1f\x00\"\x99\x02\n\x0cRedelegation\x12\x37\n\x11\x64\x65legator_address\x18\x01 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:\"delegator_address\"\x12?\n\x15validator_src_address\x18\x02 \x01(\tB \xf2\xde\x1f\x1cyaml:\"validator_src_address\"\x12?\n\x15validator_dst_address\x18\x03 \x01(\tB \xf2\xde\x1f\x1cyaml:\"validator_dst_address\"\x12@\n\x07\x65ntries\x18\x04 \x03(\x0b\x32).cosmos.staking.v1beta1.RedelegationEntryB\x04\xc8\xde\x1f\x00:\x0c\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\x98\xa0\x1f\x00\"\xae\x02\n\x06Params\x12T\n\x0eunbonding_time\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB!\xc8\xde\x1f\x00\x98\xdf\x1f\x01\xf2\xde\x1f\x15yaml:\"unbonding_time\"\x12\x31\n\x0emax_validators\x18\x02 \x01(\rB\x19\xf2\xde\x1f\x15yaml:\"max_validators\"\x12+\n\x0bmax_entries\x18\x03 \x01(\rB\x16\xf2\xde\x1f\x12yaml:\"max_entries\"\x12\x39\n\x12historical_entries\x18\x04 \x01(\rB\x1d\xf2\xde\x1f\x19yaml:\"historical_entries\"\x12)\n\nbond_denom\x18\x05 \x01(\tB\x15\xf2\xde\x1f\x11yaml:\"bond_denom\":\x08\xe8\xa0\x1f\x01\x98\xa0\x1f\x00\"\x8e\x01\n\x12\x44\x65legationResponse\x12<\n\ndelegation\x18\x01 \x01(\x0b\x32\".cosmos.staking.v1beta1.DelegationB\x04\xc8\xde\x1f\x00\x12\x30\n\x07\x62\x61lance\x18\x02 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x98\xa0\x1f\x00\"\xaf\x01\n\x19RedelegationEntryResponse\x12K\n\x12redelegation_entry\x18\x01 \x01(\x0b\x32).cosmos.staking.v1beta1.RedelegationEntryB\x04\xc8\xde\x1f\x00\x12?\n\x07\x62\x61lance\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00:\x04\xe8\xa0\x1f\x01\"\xa8\x01\n\x14RedelegationResponse\x12@\n\x0credelegation\x18\x01 \x01(\x0b\x32$.cosmos.staking.v1beta1.RedelegationB\x04\xc8\xde\x1f\x00\x12H\n\x07\x65ntries\x18\x02 \x03(\x0b\x32\x31.cosmos.staking.v1beta1.RedelegationEntryResponseB\x04\xc8\xde\x1f\x00:\x04\xe8\xa0\x1f\x00\"\xe0\x01\n\x04Pool\x12^\n\x11not_bonded_tokens\x18\x01 \x01(\tBC\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xea\xde\x1f\x11not_bonded_tokens\xc8\xde\x1f\x00\x12n\n\rbonded_tokens\x18\x02 \x01(\tBW\xea\xde\x1f\rbonded_tokens\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\xf2\xde\x1f\x14yaml:\"bonded_tokens\":\x08\xf0\xa0\x1f\x01\xe8\xa0\x1f\x01*\xb6\x01\n\nBondStatus\x12,\n\x17\x42OND_STATUS_UNSPECIFIED\x10\x00\x1a\x0f\x8a\x9d \x0bUnspecified\x12&\n\x14\x42OND_STATUS_UNBONDED\x10\x01\x1a\x0c\x8a\x9d \x08Unbonded\x12(\n\x15\x42OND_STATUS_UNBONDING\x10\x02\x1a\r\x8a\x9d \tUnbonding\x12\"\n\x12\x42OND_STATUS_BONDED\x10\x03\x1a\n\x8a\x9d \x06\x42onded\x1a\x04\x88\xa3\x1e\x00\x42.Z,github.com/cosmos/cosmos-sdk/x/staking/typesb\x06proto3')

_BONDSTATUS = DESCRIPTOR.enum_types_by_name['BondStatus']
BondStatus = enum_type_wrapper.EnumTypeWrapper(_BONDSTATUS)
BOND_STATUS_UNSPECIFIED = 0
BOND_STATUS_UNBONDED = 1
BOND_STATUS_UNBONDING = 2
BOND_STATUS_BONDED = 3


_HISTORICALINFO = DESCRIPTOR.message_types_by_name['HistoricalInfo']
_COMMISSIONRATES = DESCRIPTOR.message_types_by_name['CommissionRates']
_COMMISSION = DESCRIPTOR.message_types_by_name['Commission']
_DESCRIPTION = DESCRIPTOR.message_types_by_name['Description']
_VALIDATOR = DESCRIPTOR.message_types_by_name['Validator']
_VALADDRESSES = DESCRIPTOR.message_types_by_name['ValAddresses']
_DVPAIR = DESCRIPTOR.message_types_by_name['DVPair']
_DVPAIRS = DESCRIPTOR.message_types_by_name['DVPairs']
_DVVTRIPLET = DESCRIPTOR.message_types_by_name['DVVTriplet']
_DVVTRIPLETS = DESCRIPTOR.message_types_by_name['DVVTriplets']
_DELEGATION = DESCRIPTOR.message_types_by_name['Delegation']
_UNBONDINGDELEGATION = DESCRIPTOR.message_types_by_name['UnbondingDelegation']
_UNBONDINGDELEGATIONENTRY = DESCRIPTOR.message_types_by_name['UnbondingDelegationEntry']
_REDELEGATIONENTRY = DESCRIPTOR.message_types_by_name['RedelegationEntry']
_REDELEGATION = DESCRIPTOR.message_types_by_name['Redelegation']
_PARAMS = DESCRIPTOR.message_types_by_name['Params']
_DELEGATIONRESPONSE = DESCRIPTOR.message_types_by_name['DelegationResponse']
_REDELEGATIONENTRYRESPONSE = DESCRIPTOR.message_types_by_name['RedelegationEntryResponse']
_REDELEGATIONRESPONSE = DESCRIPTOR.message_types_by_name['RedelegationResponse']
_POOL = DESCRIPTOR.message_types_by_name['Pool']
HistoricalInfo = _reflection.GeneratedProtocolMessageType('HistoricalInfo', (_message.Message,), {
  'DESCRIPTOR' : _HISTORICALINFO,
  '__module__' : 'cosmos.staking.v1beta1.staking_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.HistoricalInfo)
  })
_sym_db.RegisterMessage(HistoricalInfo)

CommissionRates = _reflection.GeneratedProtocolMessageType('CommissionRates', (_message.Message,), {
  'DESCRIPTOR' : _COMMISSIONRATES,
  '__module__' : 'cosmos.staking.v1beta1.staking_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.CommissionRates)
  })
_sym_db.RegisterMessage(CommissionRates)

Commission = _reflection.GeneratedProtocolMessageType('Commission', (_message.Message,), {
  'DESCRIPTOR' : _COMMISSION,
  '__module__' : 'cosmos.staking.v1beta1.staking_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.Commission)
  })
_sym_db.RegisterMessage(Commission)

Description = _reflection.GeneratedProtocolMessageType('Description', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIPTION,
  '__module__' : 'cosmos.staking.v1beta1.staking_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.Description)
  })
_sym_db.RegisterMessage(Description)

Validator = _reflection.GeneratedProtocolMessageType('Validator', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATOR,
  '__module__' : 'cosmos.staking.v1beta1.staking_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.Validator)
  })
_sym_db.RegisterMessage(Validator)

ValAddresses = _reflection.GeneratedProtocolMessageType('ValAddresses', (_message.Message,), {
  'DESCRIPTOR' : _VALADDRESSES,
  '__module__' : 'cosmos.staking.v1beta1.staking_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.ValAddresses)
  })
_sym_db.RegisterMessage(ValAddresses)

DVPair = _reflection.GeneratedProtocolMessageType('DVPair', (_message.Message,), {
  'DESCRIPTOR' : _DVPAIR,
  '__module__' : 'cosmos.staking.v1beta1.staking_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.DVPair)
  })
_sym_db.RegisterMessage(DVPair)

DVPairs = _reflection.GeneratedProtocolMessageType('DVPairs', (_message.Message,), {
  'DESCRIPTOR' : _DVPAIRS,
  '__module__' : 'cosmos.staking.v1beta1.staking_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.DVPairs)
  })
_sym_db.RegisterMessage(DVPairs)

DVVTriplet = _reflection.GeneratedProtocolMessageType('DVVTriplet', (_message.Message,), {
  'DESCRIPTOR' : _DVVTRIPLET,
  '__module__' : 'cosmos.staking.v1beta1.staking_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.DVVTriplet)
  })
_sym_db.RegisterMessage(DVVTriplet)

DVVTriplets = _reflection.GeneratedProtocolMessageType('DVVTriplets', (_message.Message,), {
  'DESCRIPTOR' : _DVVTRIPLETS,
  '__module__' : 'cosmos.staking.v1beta1.staking_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.DVVTriplets)
  })
_sym_db.RegisterMessage(DVVTriplets)

Delegation = _reflection.GeneratedProtocolMessageType('Delegation', (_message.Message,), {
  'DESCRIPTOR' : _DELEGATION,
  '__module__' : 'cosmos.staking.v1beta1.staking_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.Delegation)
  })
_sym_db.RegisterMessage(Delegation)

UnbondingDelegation = _reflection.GeneratedProtocolMessageType('UnbondingDelegation', (_message.Message,), {
  'DESCRIPTOR' : _UNBONDINGDELEGATION,
  '__module__' : 'cosmos.staking.v1beta1.staking_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.UnbondingDelegation)
  })
_sym_db.RegisterMessage(UnbondingDelegation)

UnbondingDelegationEntry = _reflection.GeneratedProtocolMessageType('UnbondingDelegationEntry', (_message.Message,), {
  'DESCRIPTOR' : _UNBONDINGDELEGATIONENTRY,
  '__module__' : 'cosmos.staking.v1beta1.staking_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.UnbondingDelegationEntry)
  })
_sym_db.RegisterMessage(UnbondingDelegationEntry)

RedelegationEntry = _reflection.GeneratedProtocolMessageType('RedelegationEntry', (_message.Message,), {
  'DESCRIPTOR' : _REDELEGATIONENTRY,
  '__module__' : 'cosmos.staking.v1beta1.staking_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.RedelegationEntry)
  })
_sym_db.RegisterMessage(RedelegationEntry)

Redelegation = _reflection.GeneratedProtocolMessageType('Redelegation', (_message.Message,), {
  'DESCRIPTOR' : _REDELEGATION,
  '__module__' : 'cosmos.staking.v1beta1.staking_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.Redelegation)
  })
_sym_db.RegisterMessage(Redelegation)

Params = _reflection.GeneratedProtocolMessageType('Params', (_message.Message,), {
  'DESCRIPTOR' : _PARAMS,
  '__module__' : 'cosmos.staking.v1beta1.staking_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.Params)
  })
_sym_db.RegisterMessage(Params)

DelegationResponse = _reflection.GeneratedProtocolMessageType('DelegationResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELEGATIONRESPONSE,
  '__module__' : 'cosmos.staking.v1beta1.staking_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.DelegationResponse)
  })
_sym_db.RegisterMessage(DelegationResponse)

RedelegationEntryResponse = _reflection.GeneratedProtocolMessageType('RedelegationEntryResponse', (_message.Message,), {
  'DESCRIPTOR' : _REDELEGATIONENTRYRESPONSE,
  '__module__' : 'cosmos.staking.v1beta1.staking_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.RedelegationEntryResponse)
  })
_sym_db.RegisterMessage(RedelegationEntryResponse)

RedelegationResponse = _reflection.GeneratedProtocolMessageType('RedelegationResponse', (_message.Message,), {
  'DESCRIPTOR' : _REDELEGATIONRESPONSE,
  '__module__' : 'cosmos.staking.v1beta1.staking_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.RedelegationResponse)
  })
_sym_db.RegisterMessage(RedelegationResponse)

Pool = _reflection.GeneratedProtocolMessageType('Pool', (_message.Message,), {
  'DESCRIPTOR' : _POOL,
  '__module__' : 'cosmos.staking.v1beta1.staking_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.Pool)
  })
_sym_db.RegisterMessage(Pool)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z,github.com/cosmos/cosmos-sdk/x/staking/types'
  _BONDSTATUS._options = None
  _BONDSTATUS._serialized_options = b'\210\243\036\000'
  _BONDSTATUS.values_by_name["BOND_STATUS_UNSPECIFIED"]._options = None
  _BONDSTATUS.values_by_name["BOND_STATUS_UNSPECIFIED"]._serialized_options = b'\212\235 \013Unspecified'
  _BONDSTATUS.values_by_name["BOND_STATUS_UNBONDED"]._options = None
  _BONDSTATUS.values_by_name["BOND_STATUS_UNBONDED"]._serialized_options = b'\212\235 \010Unbonded'
  _BONDSTATUS.values_by_name["BOND_STATUS_UNBONDING"]._options = None
  _BONDSTATUS.values_by_name["BOND_STATUS_UNBONDING"]._serialized_options = b'\212\235 \tUnbonding'
  _BONDSTATUS.values_by_name["BOND_STATUS_BONDED"]._options = None
  _BONDSTATUS.values_by_name["BOND_STATUS_BONDED"]._serialized_options = b'\212\235 \006Bonded'
  _HISTORICALINFO.fields_by_name['header']._options = None
  _HISTORICALINFO.fields_by_name['header']._serialized_options = b'\310\336\037\000'
  _HISTORICALINFO.fields_by_name['valset']._options = None
  _HISTORICALINFO.fields_by_name['valset']._serialized_options = b'\310\336\037\000'
  _COMMISSIONRATES.fields_by_name['rate']._options = None
  _COMMISSIONRATES.fields_by_name['rate']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _COMMISSIONRATES.fields_by_name['max_rate']._options = None
  _COMMISSIONRATES.fields_by_name['max_rate']._serialized_options = b'\362\336\037\017yaml:\"max_rate\"\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _COMMISSIONRATES.fields_by_name['max_change_rate']._options = None
  _COMMISSIONRATES.fields_by_name['max_change_rate']._serialized_options = b'\362\336\037\026yaml:\"max_change_rate\"\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _COMMISSIONRATES._options = None
  _COMMISSIONRATES._serialized_options = b'\350\240\037\001\230\240\037\000'
  _COMMISSION.fields_by_name['commission_rates']._options = None
  _COMMISSION.fields_by_name['commission_rates']._serialized_options = b'\320\336\037\001\310\336\037\000'
  _COMMISSION.fields_by_name['update_time']._options = None
  _COMMISSION.fields_by_name['update_time']._serialized_options = b'\310\336\037\000\220\337\037\001\362\336\037\022yaml:\"update_time\"'
  _COMMISSION._options = None
  _COMMISSION._serialized_options = b'\350\240\037\001\230\240\037\000'
  _DESCRIPTION.fields_by_name['security_contact']._options = None
  _DESCRIPTION.fields_by_name['security_contact']._serialized_options = b'\362\336\037\027yaml:\"security_contact\"'
  _DESCRIPTION._options = None
  _DESCRIPTION._serialized_options = b'\350\240\037\001\230\240\037\000'
  _VALIDATOR.fields_by_name['operator_address']._options = None
  _VALIDATOR.fields_by_name['operator_address']._serialized_options = b'\362\336\037\027yaml:\"operator_address\"'
  _VALIDATOR.fields_by_name['consensus_pubkey']._options = None
  _VALIDATOR.fields_by_name['consensus_pubkey']._serialized_options = b'\312\264-\024cosmos.crypto.PubKey\362\336\037\027yaml:\"consensus_pubkey\"'
  _VALIDATOR.fields_by_name['tokens']._options = None
  _VALIDATOR.fields_by_name['tokens']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000'
  _VALIDATOR.fields_by_name['delegator_shares']._options = None
  _VALIDATOR.fields_by_name['delegator_shares']._serialized_options = b'\362\336\037\027yaml:\"delegator_shares\"\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _VALIDATOR.fields_by_name['description']._options = None
  _VALIDATOR.fields_by_name['description']._serialized_options = b'\310\336\037\000'
  _VALIDATOR.fields_by_name['unbonding_height']._options = None
  _VALIDATOR.fields_by_name['unbonding_height']._serialized_options = b'\362\336\037\027yaml:\"unbonding_height\"'
  _VALIDATOR.fields_by_name['unbonding_time']._options = None
  _VALIDATOR.fields_by_name['unbonding_time']._serialized_options = b'\310\336\037\000\220\337\037\001\362\336\037\025yaml:\"unbonding_time\"'
  _VALIDATOR.fields_by_name['commission']._options = None
  _VALIDATOR.fields_by_name['commission']._serialized_options = b'\310\336\037\000'
  _VALIDATOR.fields_by_name['min_self_delegation']._options = None
  _VALIDATOR.fields_by_name['min_self_delegation']._serialized_options = b'\362\336\037\032yaml:\"min_self_delegation\"\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000'
  _VALIDATOR._options = None
  _VALIDATOR._serialized_options = b'\350\240\037\000\230\240\037\000\210\240\037\000'
  _VALADDRESSES._options = None
  _VALADDRESSES._serialized_options = b'\230\240\037\000\200\334 \001'
  _DVPAIR.fields_by_name['delegator_address']._options = None
  _DVPAIR.fields_by_name['delegator_address']._serialized_options = b'\362\336\037\030yaml:\"delegator_address\"'
  _DVPAIR.fields_by_name['validator_address']._options = None
  _DVPAIR.fields_by_name['validator_address']._serialized_options = b'\362\336\037\030yaml:\"validator_address\"'
  _DVPAIR._options = None
  _DVPAIR._serialized_options = b'\350\240\037\000\210\240\037\000\230\240\037\000'
  _DVPAIRS.fields_by_name['pairs']._options = None
  _DVPAIRS.fields_by_name['pairs']._serialized_options = b'\310\336\037\000'
  _DVVTRIPLET.fields_by_name['delegator_address']._options = None
  _DVVTRIPLET.fields_by_name['delegator_address']._serialized_options = b'\362\336\037\030yaml:\"delegator_address\"'
  _DVVTRIPLET.fields_by_name['validator_src_address']._options = None
  _DVVTRIPLET.fields_by_name['validator_src_address']._serialized_options = b'\362\336\037\034yaml:\"validator_src_address\"'
  _DVVTRIPLET.fields_by_name['validator_dst_address']._options = None
  _DVVTRIPLET.fields_by_name['validator_dst_address']._serialized_options = b'\362\336\037\034yaml:\"validator_dst_address\"'
  _DVVTRIPLET._options = None
  _DVVTRIPLET._serialized_options = b'\350\240\037\000\210\240\037\000\230\240\037\000'
  _DVVTRIPLETS.fields_by_name['triplets']._options = None
  _DVVTRIPLETS.fields_by_name['triplets']._serialized_options = b'\310\336\037\000'
  _DELEGATION.fields_by_name['delegator_address']._options = None
  _DELEGATION.fields_by_name['delegator_address']._serialized_options = b'\362\336\037\030yaml:\"delegator_address\"'
  _DELEGATION.fields_by_name['validator_address']._options = None
  _DELEGATION.fields_by_name['validator_address']._serialized_options = b'\362\336\037\030yaml:\"validator_address\"'
  _DELEGATION.fields_by_name['shares']._options = None
  _DELEGATION.fields_by_name['shares']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _DELEGATION._options = None
  _DELEGATION._serialized_options = b'\350\240\037\000\210\240\037\000\230\240\037\000'
  _UNBONDINGDELEGATION.fields_by_name['delegator_address']._options = None
  _UNBONDINGDELEGATION.fields_by_name['delegator_address']._serialized_options = b'\362\336\037\030yaml:\"delegator_address\"'
  _UNBONDINGDELEGATION.fields_by_name['validator_address']._options = None
  _UNBONDINGDELEGATION.fields_by_name['validator_address']._serialized_options = b'\362\336\037\030yaml:\"validator_address\"'
  _UNBONDINGDELEGATION.fields_by_name['entries']._options = None
  _UNBONDINGDELEGATION.fields_by_name['entries']._serialized_options = b'\310\336\037\000'
  _UNBONDINGDELEGATION._options = None
  _UNBONDINGDELEGATION._serialized_options = b'\350\240\037\000\210\240\037\000\230\240\037\000'
  _UNBONDINGDELEGATIONENTRY.fields_by_name['creation_height']._options = None
  _UNBONDINGDELEGATIONENTRY.fields_by_name['creation_height']._serialized_options = b'\362\336\037\026yaml:\"creation_height\"'
  _UNBONDINGDELEGATIONENTRY.fields_by_name['completion_time']._options = None
  _UNBONDINGDELEGATIONENTRY.fields_by_name['completion_time']._serialized_options = b'\310\336\037\000\220\337\037\001\362\336\037\026yaml:\"completion_time\"'
  _UNBONDINGDELEGATIONENTRY.fields_by_name['initial_balance']._options = None
  _UNBONDINGDELEGATIONENTRY.fields_by_name['initial_balance']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000\362\336\037\026yaml:\"initial_balance\"'
  _UNBONDINGDELEGATIONENTRY.fields_by_name['balance']._options = None
  _UNBONDINGDELEGATIONENTRY.fields_by_name['balance']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000'
  _UNBONDINGDELEGATIONENTRY._options = None
  _UNBONDINGDELEGATIONENTRY._serialized_options = b'\350\240\037\001\230\240\037\000'
  _REDELEGATIONENTRY.fields_by_name['creation_height']._options = None
  _REDELEGATIONENTRY.fields_by_name['creation_height']._serialized_options = b'\362\336\037\026yaml:\"creation_height\"'
  _REDELEGATIONENTRY.fields_by_name['completion_time']._options = None
  _REDELEGATIONENTRY.fields_by_name['completion_time']._serialized_options = b'\310\336\037\000\220\337\037\001\362\336\037\026yaml:\"completion_time\"'
  _REDELEGATIONENTRY.fields_by_name['initial_balance']._options = None
  _REDELEGATIONENTRY.fields_by_name['initial_balance']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000\362\336\037\026yaml:\"initial_balance\"'
  _REDELEGATIONENTRY.fields_by_name['shares_dst']._options = None
  _REDELEGATIONENTRY.fields_by_name['shares_dst']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _REDELEGATIONENTRY._options = None
  _REDELEGATIONENTRY._serialized_options = b'\350\240\037\001\230\240\037\000'
  _REDELEGATION.fields_by_name['delegator_address']._options = None
  _REDELEGATION.fields_by_name['delegator_address']._serialized_options = b'\362\336\037\030yaml:\"delegator_address\"'
  _REDELEGATION.fields_by_name['validator_src_address']._options = None
  _REDELEGATION.fields_by_name['validator_src_address']._serialized_options = b'\362\336\037\034yaml:\"validator_src_address\"'
  _REDELEGATION.fields_by_name['validator_dst_address']._options = None
  _REDELEGATION.fields_by_name['validator_dst_address']._serialized_options = b'\362\336\037\034yaml:\"validator_dst_address\"'
  _REDELEGATION.fields_by_name['entries']._options = None
  _REDELEGATION.fields_by_name['entries']._serialized_options = b'\310\336\037\000'
  _REDELEGATION._options = None
  _REDELEGATION._serialized_options = b'\350\240\037\000\210\240\037\000\230\240\037\000'
  _PARAMS.fields_by_name['unbonding_time']._options = None
  _PARAMS.fields_by_name['unbonding_time']._serialized_options = b'\310\336\037\000\230\337\037\001\362\336\037\025yaml:\"unbonding_time\"'
  _PARAMS.fields_by_name['max_validators']._options = None
  _PARAMS.fields_by_name['max_validators']._serialized_options = b'\362\336\037\025yaml:\"max_validators\"'
  _PARAMS.fields_by_name['max_entries']._options = None
  _PARAMS.fields_by_name['max_entries']._serialized_options = b'\362\336\037\022yaml:\"max_entries\"'
  _PARAMS.fields_by_name['historical_entries']._options = None
  _PARAMS.fields_by_name['historical_entries']._serialized_options = b'\362\336\037\031yaml:\"historical_entries\"'
  _PARAMS.fields_by_name['bond_denom']._options = None
  _PARAMS.fields_by_name['bond_denom']._serialized_options = b'\362\336\037\021yaml:\"bond_denom\"'
  _PARAMS._options = None
  _PARAMS._serialized_options = b'\350\240\037\001\230\240\037\000'
  _DELEGATIONRESPONSE.fields_by_name['delegation']._options = None
  _DELEGATIONRESPONSE.fields_by_name['delegation']._serialized_options = b'\310\336\037\000'
  _DELEGATIONRESPONSE.fields_by_name['balance']._options = None
  _DELEGATIONRESPONSE.fields_by_name['balance']._serialized_options = b'\310\336\037\000'
  _DELEGATIONRESPONSE._options = None
  _DELEGATIONRESPONSE._serialized_options = b'\350\240\037\000\230\240\037\000'
  _REDELEGATIONENTRYRESPONSE.fields_by_name['redelegation_entry']._options = None
  _REDELEGATIONENTRYRESPONSE.fields_by_name['redelegation_entry']._serialized_options = b'\310\336\037\000'
  _REDELEGATIONENTRYRESPONSE.fields_by_name['balance']._options = None
  _REDELEGATIONENTRYRESPONSE.fields_by_name['balance']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000'
  _REDELEGATIONENTRYRESPONSE._options = None
  _REDELEGATIONENTRYRESPONSE._serialized_options = b'\350\240\037\001'
  _REDELEGATIONRESPONSE.fields_by_name['redelegation']._options = None
  _REDELEGATIONRESPONSE.fields_by_name['redelegation']._serialized_options = b'\310\336\037\000'
  _REDELEGATIONRESPONSE.fields_by_name['entries']._options = None
  _REDELEGATIONRESPONSE.fields_by_name['entries']._serialized_options = b'\310\336\037\000'
  _REDELEGATIONRESPONSE._options = None
  _REDELEGATIONRESPONSE._serialized_options = b'\350\240\037\000'
  _POOL.fields_by_name['not_bonded_tokens']._options = None
  _POOL.fields_by_name['not_bonded_tokens']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\352\336\037\021not_bonded_tokens\310\336\037\000'
  _POOL.fields_by_name['bonded_tokens']._options = None
  _POOL.fields_by_name['bonded_tokens']._serialized_options = b'\352\336\037\rbonded_tokens\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000\362\336\037\024yaml:\"bonded_tokens\"'
  _POOL._options = None
  _POOL._serialized_options = b'\360\240\037\001\350\240\037\001'
  _BONDSTATUS._serialized_start=4759
  _BONDSTATUS._serialized_end=4941
  _HISTORICALINFO._serialized_start=267
  _HISTORICALINFO._serialized_end=388
  _COMMISSIONRATES._serialized_start=391
  _COMMISSIONRATES._serialized_end=664
  _COMMISSION._serialized_start=667
  _COMMISSION._serialized_end=847
  _DESCRIPTION._serialized_start=850
  _DESCRIPTION._serialized_end=997
  _VALIDATOR._serialized_start=1000
  _VALIDATOR._serialized_end=1789
  _VALADDRESSES._serialized_start=1791
  _VALADDRESSES._serialized_end=1834
  _DVPAIR._serialized_start=1837
  _DVPAIR._serialized_end=1973
  _DVPAIRS._serialized_start=1975
  _DVPAIRS._serialized_end=2037
  _DVVTRIPLET._serialized_start=2040
  _DVVTRIPLET._serialized_end=2253
  _DVVTRIPLETS._serialized_start=2255
  _DVVTRIPLETS._serialized_end=2328
  _DELEGATION._serialized_start=2331
  _DELEGATION._serialized_end=2535
  _UNBONDINGDELEGATION._serialized_start=2538
  _UNBONDINGDELEGATION._serialized_end=2760
  _UNBONDINGDELEGATIONENTRY._serialized_start=2763
  _UNBONDINGDELEGATIONENTRY._serialized_end=3105
  _REDELEGATIONENTRY._serialized_start=3108
  _REDELEGATIONENTRY._serialized_end=3446
  _REDELEGATION._serialized_start=3449
  _REDELEGATION._serialized_end=3730
  _PARAMS._serialized_start=3733
  _PARAMS._serialized_end=4035
  _DELEGATIONRESPONSE._serialized_start=4038
  _DELEGATIONRESPONSE._serialized_end=4180
  _REDELEGATIONENTRYRESPONSE._serialized_start=4183
  _REDELEGATIONENTRYRESPONSE._serialized_end=4358
  _REDELEGATIONRESPONSE._serialized_start=4361
  _REDELEGATIONRESPONSE._serialized_end=4529
  _POOL._serialized_start=4532
  _POOL._serialized_end=4756
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/feegrant/v1beta1/genesis.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.feegrant.v1beta1 import feegrant_pb2 as cosmos_dot_feegrant_dot_v1beta1_dot_feegrant__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%cosmos/feegrant/v1beta1/genesis.proto\x12\x17\x63osmos.feegrant.v1beta1\x1a\x14gogoproto/gogo.proto\x1a&cosmos/feegrant/v1beta1/feegrant.proto\"H\n\x0cGenesisState\x12\x38\n\nallowances\x18\x01 \x03(\x0b\x32\x1e.cosmos.feegrant.v1beta1.GrantB\x04\xc8\xde\x1f\x00\x42)Z\'github.com/cosmos/cosmos-sdk/x/feegrantb\x06proto3')



_GENESISSTATE = DESCRIPTOR.message_types_by_name['GenesisState']
GenesisState = _reflection.GeneratedProtocolMessageType('GenesisState', (_message.Message,), {
  'DESCRIPTOR' : _GENESISSTATE,
  '__module__' : 'cosmos.feegrant.v1beta1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.feegrant.v1beta1.GenesisState)
  })
_sym_db.RegisterMessage(GenesisState)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\'github.com/cosmos/cosmos-sdk/x/feegrant'
  _GENESISSTATE.fields_by_name['allowances']._options = None
  _GENESISSTATE.fields_by_name['allowances']._serialized_options = b'\310\336\037\000'
  _GENESISSTATE._serialized_start=128
  _GENESISSTATE._serialized_end=200
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/protobuf/any.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19google/protobuf/any.proto\x12\x0fgoogle.protobuf\x1a\x14gogoproto/gogo.proto\"8\n\x03\x41ny\x12\x10\n\x08type_url\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x10\xf0\xa1\x1f\x00\x98\xa0\x1f\x00\xb0\xa0\x1f\x00\x80\xdc \x00\x42S\n\x13\x63om.google.protobufB\x08\x41nyProtoP\x01Z\x05types\xa2\x02\x03GPB\xaa\x02\x1eGoogle.Protobuf.WellKnownTypes\xc0\xe3\x1e\x00\x62\x06proto3')



_ANY = DESCRIPTOR.message_types_by_name['Any']
Any = _reflection.GeneratedProtocolMessageType('Any', (_message.Message,), {
  'DESCRIPTOR' : _ANY,
  '__module__' : 'google.protobuf.any_pb2'
  # @@protoc_insertion_point(class_scope:google.protobuf.Any)
  })
_sym_db.RegisterMessage(Any)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\023com.google.protobufB\010AnyProtoP\001Z\005types\242\002\003GPB\252\002\036Google.Protobuf.WellKnownTypes\300\343\036\000'
  _ANY._options = None
  _ANY._serialized_options = b'\360\241\037\000\230\240\037\000\260\240\037\000\200\334 \000'
  _ANY._serialized_start=68
  _ANY._serialized_end=124
# @@protoc_insertion_point(module_scope)
